.search_box{
    margin-bottom: 10px;
    float: left;
}
.topAction{
    margin-bottom: 10px;
    float: right;
}
.search_box input, .search_box select, .search_box a.btn{
    float: left;
    margin-right: 5px
}
.topAction a.btn{
    margin-left: 5px
}
.right_pagin{
    float: right;
    margin-top: 0;
}
.perpage{
    float: left
}
.tab-content > .active, .pill-content > .active{
    float: left
}
.table_over{
    float: left;
    width: 100%
}
.main_table th{
    font-size: 11.5px
}
.main_table td a {
    color: #333333;
}
.main_table .btn + .btn{
    margin-left: 5px
}
.orderBy{
    display: block;
    float: left;
    padding-right: 15px;
    position: relative
}
.orderBy.arrow-up:after,
.orderBy.arrow-down:after{
    content: "";
    width: 0px;
    height: 0px;
    border-style: solid;
    margin-left: 5px;
    display: inline-block;
    position: absolute;
    top: 7px;
    right: 5px;
}
.orderBy.arrow-up:after{
    border-width: 0 4.5px 4px 4.5px;
    border-color: transparent transparent #616161 transparent;
}
.orderBy.arrow-down:after{
    border-width: 4px 4.5px 0 4.5px;
    border-color: #616161 transparent transparent transparent;
}