<?php 

$lang['rtgrid_obs_helper_module'] = '<br />Модуль - "%s"';
$lang['rtgrid_obs_helper_add_record'] = 'Добавил новую <a href="{link}">запись</a>{module}';
$lang['rtgrid_obs_helper_edit_record'] = 'Изменил <a href="{link}">запись</a>{module}';
$lang['rtgrid_obs_helper_delete_record'] = 'Удалил запись(и){module}';
