<div id="data_{unique}">
    {form_open}
    <input type="hidden" name="unique" value="{unique}" />
    <input type="hidden" name="page" value="0" />
    <input type="hidden" name="order" value="" />
    <input type="hidden" name="ordertype" value="0" />
    <input type="hidden" name="action" value="" />
    <div id="search_{unique}" class="search_box">
        <input type="text" name="searchtext" value="{search_text}" maxlength="{search_text_max_length}"/>
        <select name="searchcolumn">
            {search_column}
            <option value="{value}" {selected}>{name}</option>
            {/search_column}
        </select>
        <a href="#" class="btn btn-small searchbtn"><i class="icon-search"></i> {search_btn}</a>
        <a href="#" class="btn btn-small clearbtn">{clear_btn}</a>
    </div>
    <div class="topAction">
        {top_action}
    </div>
    <table class="table table-bordered table_over main_table table-hover">
        <thead>
            <tr>
                {column}
                <th {style}>{value}</th>
                {/column}
            </tr>
        </thead>
        <tbody>
            {rows}
        </tbody>
    </table>
    <div class="perpage">
        <select name="perpage" class="span1">
            {per_page}
            <option value="{value}" {selected}>{value}</option>
            {/per_page}
        </select>
    </div>
    <div class="pagination right_pagin">
        <ul>
            {pagination}
        </ul>
    </div>
    {form_close}
</div>
