<?php 

$config['per_page_items'] = array(25, 50, 100);
$config['default_per_page'] = 25;

$config['search_text_max_length'] = 128;

$config['file_type_desc'] = 'Images';
$config['allow_types'] = '*.gif; *.jpg; *.png; *.jpeg; *.bmp;';
$config['file_types'] = array('jpg', 'jpeg', 'gif', 'png', 'bmp');