{form_open}
<ul id="myTab" class="nav nav-tabs">
    {tabs_control}
    <li {active}><a href="#{id}" data-toggle="tab">{name}</a></li>
    {/tabs_control}
</ul>
<div id="myTabContent" class="tab-content">
    {message}
    {tabs}
    <div class="tab-pane {active}" id="{id}">
        {data}
    </div>
    {/tabs}
</div>
<div class="form-actions">
    {actions}
    {action}
    {/actions}
</div>
{form_close}