<?php 

$lang['select_all'] = 'Всі';

$lang['search_btn'] = 'Пошук';
$lang['clear_btn'] = 'Очистити';

$lang['btn_delete_text'] = 'Видалити';
$lang['btn_edit_text'] = 'Редагувати';
$lang['btn_add_text'] = 'Додати';
$lang['btn_action_text'] = 'Дія';

$lang['msg_delete_data'] = 'Видалити дані?';
