<?php 

$lang['select_all'] = 'All';

$lang['search_btn'] = 'Search';
$lang['clear_btn'] = 'Clear';

$lang['btn_delete_text'] = 'Delete';
$lang['btn_edit_text'] = 'Edit';
$lang['btn_add_text'] = 'Add';
$lang['btn_action_text'] = 'Action';

$lang['msg_delete_data'] = 'Delete this data?';
